@@ -1,15 +1,13 @@
 from typing import Any, ClassVar, Dict, Union
 
 from statham.dsl.elements.base import Element, UNBOUND_PROPERTY
-from statham.dsl.elements.meta import ObjectMeta
+from statham.dsl.elements.meta import ObjectClassDict, ObjectMeta
 from statham.dsl.exceptions import ValidationError
 from statham.dsl.property import _Property
 from statham.dsl.constants import NotPassed
 
 
-# TODO: Test and support Object inheritance.
 # TODO: Test and support limited recursive models.
-# TODO: Test and support validation of setting model attributes.
 
 
 class Object(metaclass=ObjectMeta):
@@ -34,9 +32,6 @@ class Object(metaclass=ObjectMeta):
 
     """
 
-    # TODO: Add an inline constructor
-    # Object.inline("MyObject", properties={}, ...)
-
     properties: ClassVar[Dict[str, _Property]]
     default: ClassVar[Any]
     additionalProperties: ClassVar[Union[Element, bool]]
@@ -81,7 +76,7 @@ class Object(metaclass=ObjectMeta):
             value = self.default
         self._dict: Dict[str, Any] = {}
         for attr_name, attr_value in type(self).__properties__(value).items():
-            if attr_name in self.properties:
+            if attr_name in type(self).properties:
                 setattr(self, attr_name, attr_value)
             self._dict[attr_name] = attr_value
 
@@ -107,3 +102,25 @@ class Object(metaclass=ObjectMeta):
 
     def __getitem__(self, key: str) -> Any:
         return self._dict[key]
+
+    @staticmethod
+    def inline(
+        name: str, *, properties: Dict[str, Any] = None, **kwargs
+    ) -> ObjectMeta:
+        """Inline constructor for object schema elements.
+
+        Useful for minor objects, at the cost of reduced type checking
+        support.
+
+        :param name: The name of the schema element.
+        :param properties: Dictionary of properties accepted by the schema
+            element.
+        :param kwargs: Any accepted class args to `Object` subclasses.
+        :return: A new subclass of `Object` with the appropriate validation
+            rules.
+        """
+        properties = properties or {}
+        object_properties = ObjectClassDict()
+        for prop_name, prop in properties.items():
+            object_properties[prop_name] = prop
+        return ObjectMeta(name, (Object,), object_properties, **kwargs)
