@@ -1,18 +1,6 @@
-from typing import List, Union
+from typing import Any, Union
 
-from statham.dsl.constants import Maybe
-from statham.dsl.elements import (
-    AnyOf,
-    Array,
-    Boolean,
-    Integer,
-    Null,
-    Number,
-    OneOf,
-    Object,
-    ObjectOptions,
-    String,
-)
+from statham.dsl.elements import AnyOf, Integer, Null, Number, Object, String
 from statham.dsl.property import Property
 
 
